require 'open-uri'

module Elvarg #:nodoc:
  module Hiscores #:nodoc:
    ##
    # Represents different modes base URL's on the OldSchool RuneScape Hiscores.
    MODES = {
      default: 'https://secure.runescape.com/m=hiscore_oldschool/',
      ironman: 'http://services.runescape.com/m=hiscore_oldschool_ironman/',
      ultimate: 'http://services.runescape.com/m=hiscore_oldschool_ultimate/',
      hardcore: 'http://services.runescape.com/m=hiscore_oldschool_hardcore_ironman/',
      deadman: 'http://services.runescape.com/m=hiscore_oldschool_deadman/',
      seasonal: 'http://services.runescape.com/m=hiscore_oldschool_seasonal/',
      tournament: 'http://services.runescape.com/m=hiscore_oldschool_tournament/'
    }.freeze

    ##
    # Represents different endpoints on the Hiscores.
    ENDPOINTS = {
      stats: 'index_lite.ws?player=',
      scores: 'overall.ws?'
    }.freeze

    ##
    # Searches for a particular player on the Hiscores and grabs data
    # about the player.
    #
    # @param username [String] the player's username
    # @param mode [Symbol] the mode to grab data in.
    #   This can be any of the Elvarg::Hiscores::MODES.
    # @return [String] data about the Player on the Hiscores
    def self.search_for(username, mode = :default)
      open(MODES[mode] + ENDPOINTS[:stats] + username, &:read)
    end
  end
end
