require_relative '../stats/skill'

module Elvarg #:nodoc:
  module Hiscores #:nodoc:
    ##
    # Represents a Skill on the Hiscores
    class Skill < Stats::Skill
      # @return [Integer] The rank of the Skill the Player has on the Hiscores
      attr_reader :rank
      # @return [Integer] The level of the Skill the Player has on the Hiscores
      attr_reader :level
      # @return [Integer] The experience of the Skill the Player has on the Hiscores
      attr_reader :exp

      ##
      # Creates a Hiscores Skill object
      #
      # @see Stats::SKILLS
      # @see Stats::Skill#initialize
      # @param symbol [Symbol] the Symbol of the Skill (required)
      #        see Stats::SKILLS for complete list
      # @param id [Integer] the unique id of the Skill (default) 0
      # @param rank [Integer] the Player's rank in this Skill (default) -1
      # @param level [Integer] the Player's level in this Skill (default) 1
      # @param exp [Integer] the Player's experience in this Skill (default) 0
      def initialize(symbol, id = 0, rank = -1, level = 1, exp = 0)
        super(symbol, id)
        @rank = rank
        @level = level
        @exp = exp
      end
    end
  end
end
